
# Class: NodeType


Source node or Destination node.

URI: [https://w3id.org/neat/NodeType](https://w3id.org/neat/NodeType)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[ApplyTrainedModel]++-%20node_types%200..1>[NodeType&#124;source:string%20*;destination:string%20*],[ApplyTrainedModel])](https://yuml.me/diagram/nofunky;dir:TB/class/[ApplyTrainedModel]++-%20node_types%200..1>[NodeType&#124;source:string%20*;destination:string%20*],[ApplyTrainedModel])

## Referenced by Class

 *  **None** *[➞node_types](applyTrainedModel__node_types.md)*  <sub>0..1</sub>  **[NodeType](NodeType.md)**

## Attributes


### Own

 * [➞source](nodeType__source.md)  <sub>0..\*</sub>
     * Description: Source node(s).
     * Range: [String](types/String.md)
 * [➞destination](nodeType__destination.md)  <sub>0..\*</sub>
     * Description: Destination node(s).
     * Range: [String](types/String.md)
